# Acknowledgements

Diagram was inspired by the following people and projects:

* The horizontal and vertical bar are inspired by "sparklines", I have no idea
  who implemented this initially, the idea is quite wide spread.
* The axis graph is inspired by Adam Tauber's awesome
  [drawille](https://github.com/asciimoo/drawille) project.
* Lot of the terminal handling code is taken from Jeff Quast's
  [blessed](https://github.com/jquast/blessed) project.

While both the drawille and blessed projects are quite mature, the diagram
project is ought to run with just the Python standard library. This is why
we do not depend on including external packages.    